@@ -4,10 +4,10 @@ import logging
 from typing import Literal, Optional
 
 import pandas as pd
-from timeseriesflattener.feature_spec_objects import BaseModel
 
 from psycop_feature_generation.loaders.raw.sql_load import sql_load
 from psycop_feature_generation.utils import data_loaders
+from timeseriesflattener.feature_spec_objects import BaseModel
 
 log = logging.getLogger(__name__)
 
@@ -142,11 +142,17 @@ def physical_visits(
     # Concat the list of dfs
     output_df = pd.concat(dfs)
 
-    # 0,8% of visits are duplicates. Unsure if overlap between sources or errors in source data. Removing.
+    # Round timestamps to whole seconds before dropping duplicates
+    output_timestamp_col_name = f"timestamp_{timestamp_for_output}"
+
+    output_df[output_timestamp_col_name] = output_df[
+        output_timestamp_col_name
+    ].dt.round("1s")
     output_df = output_df.drop_duplicates(
-        subset=["timestamp_start", "timestamp_end", "dw_ek_borger"],
+        subset=[output_timestamp_col_name, "dw_ek_borger"],
         keep="first",
     )
+    output_df = output_df.dropna(subset=[output_timestamp_col_name])
 
     # Change value column to length of admission in days
     if return_value_as_visit_length_days:
@@ -158,14 +164,7 @@ def physical_visits(
 
     log.info("Loaded physical visits")
 
-    output_df.rename(
-        columns={f"timestamp_{timestamp_for_output}": "timestamp"}, inplace=True
-    )
-
-    # Keep only one visit per timestamp
-    output_df = output_df.drop_duplicates(
-        subset=["dw_ek_borger", "timestamp"], keep="first"
-    )
+    output_df.rename(columns={output_timestamp_col_name: "timestamp"}, inplace=True)
 
     return output_df[["dw_ek_borger", f"timestamp", "value"]].reset_index(drop=True)
 
